==> zeusmp1.5.10.tar.gz: zeusmp/src/options.h <==
#ifdef XYZ
#define GEOMETRY_OPTION "(14x,'* geometry:        XYZ')"
#endif
#ifdef ZRP
#define GEOMETRY_OPTION "(14x,'* geometry:        ZRP')"
#endif
#ifdef RTP
#define GEOMETRY_OPTION "(14x,'* geometry:        RTP')"
#endif

#ifdef MOVING_GRID
#define GRID_OPTION    "(14x,'* moving grid      ON ')"
#else
#define GRID_OPTION    "(14x,'* moving grid      OFF')"
#endif

#ifdef PT_MASS
#define PT_MASS_OPTION "(14x,'* point masses     ON ')"
#else
#define PT_MASS_OPTION "(14x,'* point masses     OFF')"
#endif

#if defined GRAV || defined GRAV_FFT
#define GRAVITY_OPTION "(14x,'* self-gravity     ON ')"
#ifdef GRAV_FFT
#define PS_OPTION      "(14x,'* Poisson solver   FFTW ')"
#else
#define PS_OPTION      "(14x,'* Poisson solver   MGMPI')"
#endif /* GRAV_FFT */
#else
#define GRAVITY_OPTION "(14x,'* self-gravity     OFF')"
#endif /* GRAV || GRAV_FFT */

#ifdef MHD
#define MHD_OPTION "(14x,'* magnetic fields  ON ')"
#else
#define MHD_OPTION "(14x,'* magnetic fields  OFF')"
#endif

#ifdef RAD
#define RAD_IMP_OPTION "(14x,'* implicit rad alg ON ')"
#else
#define RAD_IMP_OPTION "(14x,'* implicit rad alg OFF')"
#endif

#ifdef RAD_EXP
#define RAD_EXP_OPTION "(14x,'* PF rad algorithm ON ')"
#else
#define RAD_EXP_OPTION "(14x,'* PF rad algorithm OFF')"
#endif

#ifdef SINGLE_PRECISION
#define PRECISION_OPTION "(14x,'* precision:       SGL')"
#else
#define PRECISION_OPTION "(14x,'* precision:       DBL')"
#endif

#ifdef NO_CPU_TIMER_USED
#define CPU_TIMER_OPTION "(14x,'* thread time:     WAL')"
#else
#define CPU_TIMER_OPTION "(14x,'* thread time:     CPU')"
#endif

#ifdef PROFILING
#define PROFILING_OPTION "(14x,'* profiling        ON ')"
#else
#define PROFILING_OPTION "(14x,'* profiling        OFF')"
#endif

#ifdef MPI_USED
#define MPI_OPTION "(14x,'* message passing  ON ')"
#else
#define MPI_OPTION "(14x,'* message passing  OFF')"
#endif

#ifdef MPE_USED
#define MPE_OPTION "(14x,'* MP Environment   ON ')"
#else
#define MPE_OPTION "(14x,'* MP Environment   OFF')"
#endif

#ifdef DEBUG
#define DEBUG_OPTION "(14x,'* debug messages   ON ')"
#else
#define DEBUG_OPTION "(14x,'* debug messages   OFF')"
#endif

#ifdef RES_DUMPS
#define RES_DUMPS_OPTION "(14x,'* restart dumps    ON ')"
#else
#define RES_DUMPS_OPTION "(14x,'* restart dumps    OFF')"
#endif

#ifdef HDF_DUMPS
#define HDF_DUMPS_OPTION "(14x,'* HDF dumps        ON ')"
#else
#define HDF_DUMPS_OPTION "(14x,'* HDF dumps        OFF')"
#endif

#ifdef TSL_DUMPS
#define TSL_DUMPS_OPTION "(14x,'* TSL dumps        ON ')"
#else
#define TSL_DUMPS_OPTION "(14x,'* TSL dumps        OFF')"
#endif

#ifdef HST_DUMPS
#define HST_DUMPS_OPTION "(14x,'* history dumps    ON ')"
#else
#define HST_DUMPS_OPTION "(14x,'* history dumps    OFF')"
#endif

#ifdef TXT_DUMPS
#define TXT_DUMPS_OPTION "(14x,'* text dumps       ON ')"
#else
#define TXT_DUMPS_OPTION "(14x,'* text dumps       OFF')"
#endif

#ifdef RAD_LOSS
#define RAD_LOSS_OPTION "(14x,'* radiative cooling ON ')"
#else
#define RAD_LOSS_OPTION "(14x,'* radiative cooling OFF')"
#endif /*RAD_LOSS*/

#ifdef PHYS_VISC
#define VISC_OPTION "(14x,'* kinetic viscosity ON ')"
#else
#define VISC_OPTION "(14x,'* kinetic viscosity OFF')"
#endif /*PHYS_VISC*/

#ifdef T_CONDUCT
#define CONDUCT_OPTION "(14x,'* thermal conduction ON ')"
#else
#define CONDUCT_OPTION "(14x,'* thermal conduction OFF')"
#endif /*T_CONDUCT*/

#ifndef PNEWT
#define FORCE_OPTION "(14x,'* using normal forces ')"
#else
#define FORCE_OPTION "(14x,'* using pseudo newtonian force law ')"
#endif

#ifdef ALFVENLIMIT
#define ALFLIMIT_OPTION "(14x,'* alfven limiter ON ')"
#else
#define ALFLIMIT_OPTION "(14x,'* alvfen limiter OFF')"
#endif /* ALFVENLIMIT */

==> zeusmp1.5.13.tar.gz: zeusmp/src/options.h <==
#ifdef XYZ
#define GEOMETRY_OPTION "(14x,'* geometry:        XYZ')"
#endif
#ifdef ZRP
#define GEOMETRY_OPTION "(14x,'* geometry:        ZRP')"
#endif
#ifdef RTP
#define GEOMETRY_OPTION "(14x,'* geometry:        RTP')"
#endif

#ifdef MOVING_GRID
#define GRID_OPTION    "(14x,'* moving grid      ON ')"
#else
#define GRID_OPTION    "(14x,'* moving grid      OFF')"
#endif

#ifdef PT_MASS
#define PT_MASS_OPTION "(14x,'* point masses     ON ')"
#else
#define PT_MASS_OPTION "(14x,'* point masses     OFF')"
#endif

#if defined GRAV
#define GRAVITY_OPTION "(14x,'* background-gravity ON ')"
#else
#define GRAVITY_OPTION "(14x,'* background-gravity OFF')"
#endif /* GRAV */

#if defined GRAV && defined GRAV_FFT
#define SELF_GRAVITY_OPTION "(14x,'* self-gravity     ON ')"
#ifdef GRAV_FFT
#define PS_OPTION      "(14x,'* Poisson solver   FFTW ')"
#else
#define PS_OPTION      "(14x,'* Poisson solver   MGMPI')"
#endif /* GRAV_FFT */
#else
#define SELF_GRAVITY_OPTION "(14x,'* self-gravity     OFF')"
#endif /* GRAV && GRAV_FFT */

#ifdef MHD
#define MHD_OPTION "(14x,'* magnetic fields  ON ')"
#else
#define MHD_OPTION "(14x,'* magnetic fields  OFF')"
#endif

#ifdef RAD
#define RAD_IMP_OPTION "(14x,'* implicit rad alg ON ')"
#else
#define RAD_IMP_OPTION "(14x,'* implicit rad alg OFF')"
#endif

#ifdef RAD_EXP
#define RAD_EXP_OPTION "(14x,'* PF rad algorithm ON ')"
#else
#define RAD_EXP_OPTION "(14x,'* PF rad algorithm OFF')"
#endif

#ifdef SINGLE_PRECISION
#define PRECISION_OPTION "(14x,'* precision:       SGL')"
#else
#define PRECISION_OPTION "(14x,'* precision:       DBL')"
#endif

#ifdef NO_CPU_TIMER_USED
#define CPU_TIMER_OPTION "(14x,'* thread time:     WAL')"
#else
#define CPU_TIMER_OPTION "(14x,'* thread time:     CPU')"
#endif

#ifdef PROFILING
#define PROFILING_OPTION "(14x,'* profiling        ON ')"
#else
#define PROFILING_OPTION "(14x,'* profiling        OFF')"
#endif

#ifdef MPI_USED
#define MPI_OPTION "(14x,'* message passing  ON ')"
#else
#define MPI_OPTION "(14x,'* message passing  OFF')"
#endif

#ifdef MPE_USED
#define MPE_OPTION "(14x,'* MP Environment   ON ')"
#else
#define MPE_OPTION "(14x,'* MP Environment   OFF')"
#endif

#ifdef DEBUG
#define DEBUG_OPTION "(14x,'* debug messages   ON ')"
#else
#define DEBUG_OPTION "(14x,'* debug messages   OFF')"
#endif

#ifdef RES_DUMPS
#define RES_DUMPS_OPTION "(14x,'* restart dumps    ON ')"
#else
#define RES_DUMPS_OPTION "(14x,'* restart dumps    OFF')"
#endif

#ifdef HDF_DUMPS
#define HDF_DUMPS_OPTION "(14x,'* HDF dumps        ON ')"
#else
#define HDF_DUMPS_OPTION "(14x,'* HDF dumps        OFF')"
#endif

#ifdef TSL_DUMPS
#define TSL_DUMPS_OPTION "(14x,'* TSL dumps        ON ')"
#else
#define TSL_DUMPS_OPTION "(14x,'* TSL dumps        OFF')"
#endif

#ifdef HST_DUMPS
#define HST_DUMPS_OPTION "(14x,'* history dumps    ON ')"
#else
#define HST_DUMPS_OPTION "(14x,'* history dumps    OFF')"
#endif

#ifdef TXT_DUMPS
#define TXT_DUMPS_OPTION "(14x,'* text dumps       ON ')"
#else
#define TXT_DUMPS_OPTION "(14x,'* text dumps       OFF')"
#endif

#ifdef RAD_LOSS
#define RAD_LOSS_OPTION "(14x,'* radiative cooling ON ')"
#else
#define RAD_LOSS_OPTION "(14x,'* radiative cooling OFF')"
#endif /*RAD_LOSS*/

#ifdef PHYS_VISC
#define VISC_OPTION "(14x,'* kinetic viscosity ON ')"
#else
#define VISC_OPTION "(14x,'* kinetic viscosity OFF')"
#endif /*PHYS_VISC*/

#ifdef T_CONDUCT
#define CONDUCT_OPTION "(14x,'* thermal conduction ON ')"
#else
#define CONDUCT_OPTION "(14x,'* thermal conduction OFF')"
#endif /*T_CONDUCT*/

#ifndef PNEWT
#define FORCE_OPTION "(14x,'* using normal forces ')"
#else
#define FORCE_OPTION "(14x,'* using pseudo newtonian force law ')"
#endif

#ifdef ALFVENLIMIT
#define ALFLIMIT_OPTION "(14x,'* alfven limiter ON ')"
#else
#define ALFLIMIT_OPTION "(14x,'* alvfen limiter OFF')"
#endif /* ALFVENLIMIT */
